import { ImageProxyServer, FetchResponse, ImageProxyError, ImageProxyDataType, ReportResponse, DescribeResponse, DescribeReportsResponse, ModerationLabel } from "./types";
/**
 * Returns a fetch reponse from specified image proxy with the image data in it
 * @param {Server} server - Server configuration object
 * @param {string} url - Url of the image to fetch
 * @param {ImageProxyDataType} response_type - Data type of response. Either raw bytes or json response
 * @param {boolean} force - Whether or not image should be returned if it is potentially blocked
 * @returns {Promise<FetchResponse | ImageProxyError>} Image proxy reponse or error
 */
export declare function proxyFetch(server: ImageProxyServer, url: string, response_type: ImageProxyDataType, force: boolean): Promise<FetchResponse | ImageProxyError>;
/**
 * Returns a moderated fetch reponse from specified image proxy with the image data in it, blocking unsafe images
 * @param {Server} server - Server configuration object
 * @param {string} url - Url of the image to fetch
 * @param {ImageProxyDataType} response_type - Data type of response. Either raw bytes or json response
 * @returns {Promise<FetchResponse | ImageProxyError>} Image proxy reponse or error
 */
export declare function safeFetch(server: ImageProxyServer, url: string, response_format: ImageProxyDataType): Promise<FetchResponse | ImageProxyError>;
/**
 * Returns an unmoderated fetch reponse from specified image proxy with the image data in it, allowing all images
 * @param {Server} server - Server configuration object
 * @param {string} url - Url of the image to fetch
 * @param {ImageProxyDataType} response_type - Data type of response. Either raw bytes or json response
 * @returns {Promise<FetchResponse | ImageProxyError>} Image proxy reponse or error
 */
export declare function unsafeFetch(server: ImageProxyServer, url: string, response_format: ImageProxyDataType): Promise<FetchResponse | ImageProxyError>;
/**
 * Describes the moderation status of provided urls
 * @param {Server} server - Server configuration object
 * @param {string} urls - List of urls of the images to describe
 * @returns {Promise<DescribeResponse | ImageProxyError>} Describe reponse or error
 */
export declare function describe(server: ImageProxyServer, urls: string[]): Promise<DescribeResponse | ImageProxyError>;
/**
 * Report a url that was deemed safe but should be blocked
 * @param {Server} server - Server configuration object
 * @param {string} urls - List of urls of the images to report
 * @param {ModerationLabel[]} categories - List of moderation labels to report the image as
 * @returns {Promise<ReportResponse | ImageProxyError>} Report reponse or error
 */
export declare function report(server: ImageProxyServer, url: string, categories: ModerationLabel[]): Promise<ReportResponse | ImageProxyError>;
/**
 * Describe all reports submitted to image proxy
 * @param {Server} server - Server configuration object
 * @returns {Promise<DescribeReportResponse | ImageProxyError>} Describe report response or error
 */
export declare function describeReports(server: ImageProxyServer): Promise<DescribeReportsResponse | ImageProxyError>;
